@@ -30,16 +30,16 @@
 #include <kmessagebox.h>
 #include <kmimetypetrader.h>
 #include <kservice.h>
-#include <KIO/OpenUrlJob>
-#include <KIO/JobUiDelegate>
+#include <KIO/CommandLauncherJob>
+#include <KIO/ApplicationLauncherJob>
 #include <KStartupInfo>
 #include <kurifilter.h>
 #include <KConfig>
 #include <KConfigGroup>
-#include <KJobWidgets>
 #include <KService>
 #include <KAboutData>
 #include <KWindowSystem>
+#include <KShell>
 
 #include <kcoreaddons_version.h>
 
@@ -48,14 +48,10 @@
 #include <QDir>
 #include <QMimeDatabase>
 #include <QUrl>
-#include <QStandardPaths>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QTimer>
 
-#if KONQ_HAVE_X11
-#include <QX11Info>
-#endif
 #ifdef WIN32
 #include <process.h>
 #endif
@@ -173,44 +169,102 @@ ClientApp::ClientApp()
 {
 }
 
+ClientApp::BrowserApplicationParsingResult ClientApp::parseBrowserApplicationString(const QString& str)
+{
+    // There is a configured browser application.
+    // See whether it is a literal command (starting with '!')
+    // or a service (no '!').
+    BrowserApplicationParsingResult res;
+    if (str.isEmpty()) {
+        return res;
+    }
+    res.isCommand = str.startsWith('!');
+    if (res.isCommand) {
+        // A literal command.  Split the string up into a shell
+        // command and arguments.
+        res.args = KShell::splitArgs(str.mid(1), KShell::AbortOnMeta);
+        res.isValid = !res.args.isEmpty();
+        if (res.isValid) {
+            res.commandOrService = res.args.takeFirst();
+        }
+        else {
+            res.error = "Parsing browser command failed";
+        }
+    } else {
+        res.commandOrService = str;
+        res.isValid = true;
+    }
+    // Ensure that we are not calling ourselves recursively;
+    // that is, the external command is not "kfmclient" or
+    // any variation of it.
+    if (res.commandOrService.startsWith("kfmclient")) {
+        res.isValid = false;
+        res.error = "Recursive external browser command or service detected";
+    }
+    return res;
+}
+
+bool ClientApp::launchExternalBrowser(const ClientApp::BrowserApplicationParsingResult& parseResult, const QUrl& url, bool tempFile)
+{
+    KJob *job = nullptr;
+    if (parseResult.isCommand) {
+        QStringList args(parseResult.args);
+        args << url.url();
+        KStartupInfo::appStarted();
+        job =  new KIO::CommandLauncherJob(parseResult.commandOrService, args);
+    } else {
+        KService::Ptr service = KService::serviceByStorageId(parseResult.commandOrService);
+        if (!service) {
+            qCWarning(KFMCLIENT_LOG) << "External browser service not known:" << parseResult.commandOrService;
+            return false;
+        }
+        auto launcherJob = new KIO::ApplicationLauncherJob(service);
+        launcherJob->setUrls({url});
+        if (tempFile) {
+            launcherJob->setRunFlags(KIO::ApplicationLauncherJob::DeleteTemporaryFiles);
+        }
+        job = launcherJob;
+    }
+    QObject::connect(job, &KJob::result, this, &ClientApp::slotResult);
+    job->setUiDelegate(nullptr);
+    job->start();
+    return qApp->exec() == 0;
+}
+
 bool ClientApp::createNewWindow(const QUrl &url, bool newTab, bool tempFile, const QString &mimetype)
 {
     qCDebug(KFMCLIENT_LOG) << url << "mimetype=" << mimetype;
 
+    bool launched = false;
+
     if (url.scheme().startsWith(QLatin1String("http"))) {
         KConfig config(QStringLiteral("kfmclientrc"));
         KConfigGroup generalGroup(&config, "General");
         const QString browserApp = generalGroup.readEntry("BrowserApplication");
-        if (!browserApp.isEmpty() && !browserApp.startsWith(QLatin1String("!kfmclient"))
-                && (browserApp.startsWith('!') || KService::serviceByStorageId(browserApp))) {
-            qCDebug(KFMCLIENT_LOG) << "Using external browser" << browserApp;
-            KStartupInfo::appStarted();
-
-            KIO::OpenUrlJob *job = new KIO::OpenUrlJob(url);
-            //job->setUiDelegate(new KIO::JobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, window));
-            job->setDeleteTemporaryFile(tempFile);
-            job->setUiDelegate(nullptr);
-            job->start();
-
-            QObject::connect(job, &KJob::result, this, [this](KJob *job) {
-                if (job->error()) {
-                    qApp->exit(1);
-                } else {
-                    ClientApp::delayedQuit();
-                }
-            });
-            return qApp->exec();
+        if (!browserApp.isEmpty()) {
+            //Parse the BrowserApplication string and act accordingly
+            BrowserApplicationParsingResult parseRes = parseBrowserApplicationString(browserApp);
+            qCDebug(KFMCLIENT_LOG) << "Using external browser" << (parseRes.isCommand ? "command" : "service") << browserApp;
+            if (parseRes.isValid) {
+                launched = launchExternalBrowser(parseRes, url, tempFile);
+            } else {
+                qCWarning(KFMCLIENT_LOG) << parseRes.error;
+            }
         }
     }
 
-    needDBus();
+    if (!launched) {
+        needDBus();
+        // Launch Konqueror, or reuse an existing instance if possible.
+        KonqClientRequest req;
+        req.setUrl(url);
+        req.setNewTab(newTab);
+        req.setTempFile(tempFile);
+        req.setMimeType(mimetype);
+        launched = req.openUrl();
+    }
 
-    KonqClientRequest req;
-    req.setUrl(url);
-    req.setNewTab(newTab);
-    req.setTempFile(tempFile);
-    req.setMimeType(mimetype);
-    return req.openUrl();
+    return launched;
 }
 
 bool ClientApp::openProfile(const QString &profileName, const QUrl &url, const QString &mimetype)
@@ -223,7 +277,7 @@ void ClientApp::delayedQuit()
 {
     // Quit in 2 seconds. This leaves time for OpenUrlJob to pop up
     // "app not found" in KProcessRunner, if that was the case.
-    QTimer::singleShot(2000, qApp, SLOT(quit()));
+    QTimer::singleShot(2000, qApp, &QApplication::quit);
 }
 
 static void checkArgumentCount(int count, int min, int max)
@@ -288,13 +342,12 @@ bool ClientApp::doIt(const QCommandLineParser &parser)
     return true;
 }
 
+
 void ClientApp::slotResult(KJob *job)
 {
-    if (job->error() && m_interactive) {
-        KJobWidgets::setWindow(job, nullptr);
-        job->uiDelegate()->showErrorMessage();
+    if (job->error()) {
+        qApp->exit(1);
+    } else {
+        delayedQuit();
     }
-    const bool ok = !job->error();
-    qApp->exit(ok ? 0 : 1);
 }
-
