@@ -41,6 +41,10 @@
 #include "webenginewallet.h"
 #include "webengineparterrorschemehandler.h"
 #include "webenginepartcookiejar.h"
+#include "webengineurlrequestinterceptor.h"
+#include "spellcheckermanager.h"
+#include "webenginepartdownloadmanager.h"
+#include "webenginepartcontrols.h"
 
 #include "ui/searchbar.h"
 #include "ui/passwordbar.h"
@@ -73,7 +77,6 @@
 #include <KSharedConfig>
 #include <KSslInfoDialog>
 #include <KProtocolManager>
-#include <KProtocolInfo>
 #include <KParts/PartActivateEvent>
 #include <KParts/BrowserInterface>
 #include <KIO/ApplicationLauncherJob>
@@ -86,29 +89,22 @@
 #include <QMenu>
 #include <QStatusBar>
 #include <QWebEngineScriptCollection>
-#include <QWebEngineUrlScheme>
+#include <QWebEngineScript>
+#include <QDir>
+
 #include "utils.h"
 #include <kio_version.h>
 
-void WebEnginePart::initWebEngineUrlSchemes()
-{
-    static bool needToInitUrlSchemes = true;
-    if (needToInitUrlSchemes) {
-        needToInitUrlSchemes = false;
-        QVector<QByteArray> localSchemes = {"error", "konq", "tar"};
-        const QStringList protocols = KProtocolInfo::protocols();
-        for(const QString &prot : protocols){
-            if (KProtocolInfo::defaultMimetype(prot) == "text/html") {
-                localSchemes.append(QByteArray(prot.toLatin1()));
-            }
-        }
-        for (const QByteArray &name : qAsConst(localSchemes)){
-            QWebEngineUrlScheme scheme(name);
-            scheme.setFlags(QWebEngineUrlScheme::LocalScheme|QWebEngineUrlScheme::LocalAccessAllowed);
-            scheme.setSyntax(QWebEngineUrlScheme::Syntax::Path);
-            QWebEngineUrlScheme::registerScheme(scheme);
-        }
+static QWebEngineScript detectRefreshScript() {
+    static QWebEngineScript s_detectRefreshScript;
+    if (s_detectRefreshScript.isNull()) {
+        QFile jsfile(":/hasrefresh.js");
+        jsfile.open(QIODevice::ReadOnly);
+        s_detectRefreshScript.setSourceCode(QString(jsfile.readAll()));
+        s_detectRefreshScript.setInjectionPoint(QWebEngineScript::DocumentCreation);
+        s_detectRefreshScript.setWorldId(QWebEngineScript::ApplicationWorld);
     }
+    return s_detectRefreshScript;
 }
 
 WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
@@ -125,15 +121,10 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
              m_passwordBar(nullptr),
              m_wallet(nullptr)
 {
-    initWebEngineUrlSchemes();
-    QWebEngineProfile *prof = QWebEngineProfile::defaultProfile();
-    if (!prof->urlSchemeHandler("error")) {
-        prof->installUrlSchemeHandler("error", new WebEnginePartErrorSchemeHandler(prof));
-        prof->installUrlSchemeHandler("konq", new KonqUrlSchemeHandler(prof));
-        prof->installUrlSchemeHandler("help", new WebEnginePartKIOHandler(prof));
-        prof->installUrlSchemeHandler("tar", new WebEnginePartKIOHandler(prof));
+    if (!WebEnginePartControls::self()->isReady()) {
+        WebEnginePartControls::self()->setup(QWebEngineProfile::defaultProfile());
     }
-    static WebEnginePartCookieJar s_cookieJar(prof, nullptr);
+
 #if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
     setMetaData(metaData);
 #else
@@ -216,6 +207,7 @@ WebEnginePart::WebEnginePart(QWidget *parentWidget, QObject *parent,
     connect(m_webView, &QWebEngineView::loadFinished,
             this, &WebEnginePart::slotLoadFinished);
 
+    page()->scripts().insert(detectRefreshScript());
     // Connect the signals from the page...
     connectWebEnginePageSignals(page());
 
@@ -248,6 +240,16 @@ const WebEnginePage* WebEnginePart::page() const
     return nullptr;
 }
 
+WebEnginePartDownloadManager * WebEnginePart::downloadManager()
+{
+    return WebEnginePartControls::self()->downloadManager();
+}
+
+SpellCheckerManager * WebEnginePart::spellCheckerManager()
+{
+    return WebEnginePartControls::self()->spellCheckerManager();
+}
+
 void WebEnginePart::initActions()
 {
     KStandardAction::create(KStandardAction::SaveAs, m_browserExtension, &WebEngineBrowserExtension::slotSaveDocument,
@@ -544,19 +546,15 @@ void WebEnginePart::slotLoadFinished (bool ok)
         m_wallet->detectAndFillPageForms(page());
     }
 
-    bool pending = false;
-       // QWebFrame* frame = (page() ? page()->currentFrame() : 0);
-       // if (ok &&
-       //     frame == page()->mainFrame() &&
-       //     !frame->findFirstElement(QL1S("head>meta[http-equiv=refresh]")).isNull()) {
-       //     if (WebEngineSettings::self()->autoPageRefresh()) {
-       //         pending = true;
-       //     } else {
-       //         frame->page()->triggerAction(QWebEnginePage::Stop);
-       //     }
-       // }
-    emit completed ((ok && pending));
-
+    auto callback = [this](const QVariant &res) {
+        bool hasRefresh = res.toBool();
+#if KPARTS_VERSION < QT_VERSION_CHECK(5, 81, 0)
+        emit completed(hasRefresh);
+#else
+        emit hasRefresh ? completedWithPendingAction() : completed();
+#endif
+    };
+    page()->runJavaScript("hasRefreshAttribute()", QWebEngineScript::ApplicationWorld, callback);
     updateActions();
 }
 
